@@ -511,14 +511,16 @@ class UARTSensor(Sensor):
 
     _clk_stretch = True
     _serial_mode = "UART"
-    port = None
+    port = ""
+    dev = None
 
-    def __init__(self, bus):
+    def __init__(self, port: str, loglvl: logging.INFO):
         """
-        Base class for all I2C Sensors
+        Base class for all COM port sensors
         """
-        self.bus = bus
+        self.port = port
         self._logger = logging.getLogger(self.__str__())
+        self._logger.setLevel(loglvl)
 
     def default_data(self):
         """
@@ -562,14 +564,14 @@ class UARTSensor(Sensor):
         if type(cmd) == list:
             cmd = [cmd]
 
-        self.bus.write(cmd)
+        self.dev.write(cmd)
         data = None
         if readlen > 0:
-            resp = self.bus.inWaiting()
+            resp = self.dev.inWaiting()
             while resp < readlen:
-                resp = self.bus.inWaiting()
+                resp = self.dev.inWaiting()
                 time.sleep(t_wait)
-            data = self.ser.read(resp)
+            data = self.dev.read(resp)
 
         return data
 
