@@ -23,6 +23,7 @@ from ..devices.qwiicrelay import QwiicQuadRelay
 from ..devices.sps30 import SPS30
 from ..devices.smgair2 import SMGair2
 from ..devices.s8000 import S8000
+from ..devices.optidew import Optidew
 
 # For type checking
 from ..core.i2controller import MmsI2cController as I2cController
@@ -40,7 +41,7 @@ FTDI_SENSOR_CLASSES = [
     QwiicQuadRelay,
 ]
 
-UART_SENSOR_CLASSES = [SPS30, SMGair2, S8000]
+UART_SENSOR_CLASSES = [SPS30, SMGair2, S8000, Optidew]
 
 
 def scan_spi(spibus, loglvl: int = logging.ERROR, **kwargs):
@@ -94,6 +95,10 @@ def get_min_frequency(sensor_classes):
 
 def scan_uart(port: str, measurement_obj=None, **kwargs):
     """"""
+    invalid_substrings = ["ttyS", "ttyprintk"]
+    for substring in invalid_substrings:
+        if substring in port:
+            return None
 
     if type(port) is not str:
         raise TypeError(
