@@ -1,17 +1,15 @@
-# SPDX-FileCopyrightText: 2021 German Aerospace Center (DLR)
-#
+# SPDX-FileCopyrightText: 2022 German Aerospace Center (DLR)
 # SPDX-License-Identifier: MIT
 
+
 """
-SHT3X and similar e.g. SHT85
-class includes the function to control the SHT3X humidity sensors via I2C
+SHT85 - Humidty and Temperature sensors
+class includes the function to control the SHT85 humidity sensors via I2C
 """
 
 from ..core.error import Error
 from ..core.sensor import I2CSensor
 
-# import logging
-# logging.basicConfig(level=logging.DEBUG)
 
 try:
     import struct
@@ -48,8 +46,10 @@ class SHT85(I2CSensor):
 
     def reset(self):
         """
-        reseting the sensor
-        :return: True for successful reset else False
+        Reseting the sensor
+
+        Returns:
+            bool: True for successful reset else False
         """
         try:
             self.txrx([0x30, 0xA2], readlen=0)
@@ -66,9 +66,12 @@ class SHT85(I2CSensor):
 
     def get_serial_number(self):
         """
-        reads unique serial number of sensor
-        :return: [STRING] serial number of the sensor
+        Reads unique serial number of sensor
+
+        Returns:
+             str: serial number of the sensor
         """
+
         self.serial_number = None
         self.error = None
         ba = self.txrx([0x36, 0x82], readlen=6)
@@ -91,11 +94,12 @@ class SHT85(I2CSensor):
 
     def prepare_measurement(self):
         """
-        initialises a continuous measurement of the mass flow
-        :return: continuous measurement established
-        (True = successful | False = failed)
-        :rtype: bool
+        Initializes a continuous measurement of the mass flow
+
+        Returns:
+            bool: continuous measurement established (True = successful | False = failed)
         """
+
         try:
             self.heater()
             self.exists = self.sensor_exists()
@@ -104,14 +108,17 @@ class SHT85(I2CSensor):
         except IOError:
             return False
 
-    def get_data(self, scale_factor=175, offset=-45):
-        """
-        :param scale_factor: [INT] sensor specific parameter for the
-        calculation of the volume flow
-        :param offset: [INT] sensor specific parameter for the
-        calculation of the volume flow
-        :return: [DICT] data dictionary
+    def get_data(self, scale_factor: int = 175, offset: int = -45):
+        """Read temperature and humidty from sensor
+
+        Args:
+            scale_factor (int): sensor specific parameter for the calculation of the volume flow
+            offset (int): sensor specific parameter for the calculation of the volume flow
+
+        Returns:
+            dict: data dictionary
         """
+
         data = None
         max_attempts = 10
         attempts = 0
