@@ -23,6 +23,7 @@ if __name__ == "__main__":
 
     print(device)
     # start measurement
-    for device in devices:
-        values = device.get_data()
-        print(values)
+    for i in range(10):
+        for device in devices:
+            values = device.get_data()
+            print(values)
